@@ -5,10 +5,12 @@ import (
 	"encoding/json"
 	"fmt"
 	"log/slog"
+	"math"
 	"os"
 	"sync"
 	"time"
 
+	"github.com/jsdelivr/globalping-cli/globalping"
 	"github.com/knadh/koanf/providers/posflag"
 	"github.com/knadh/koanf/v2"
 	"github.com/mr-karan/doggo/internal/app"
@@ -43,6 +45,26 @@ func main() {
 	logger := utils.InitLogger(cfg.debug)
 	app := initializeApp(logger, cfg)
 
+	if app.QueryFlags.GPFrom != "" {
+		res, err := app.GlobalpingMeasurement()
+		if err != nil {
+			logger.Error("Error fetching globalping measurement", "error", err)
+			os.Exit(2)
+		}
+		if app.QueryFlags.ShowJSON {
+			err = app.OutputGlobalpingJSON(res)
+		} else if app.QueryFlags.ShortOutput {
+			err = app.OutputGlobalpingShort(res)
+		} else {
+			err = app.OutputGlobalping(res)
+		}
+		if err != nil {
+			logger.Error("Error outputting globalping measurement", "error", err)
+			os.Exit(2)
+		}
+		return
+	}
+
 	if cfg.reverseLookup {
 		app.ReverseLookup()
 	}
@@ -121,6 +143,9 @@ func setupFlags() *flag.FlagSet {
 	f.StringSliceP("nameserver", "n", []string{}, "Address of the nameserver to send packets to")
 	f.BoolP("reverse", "x", false, "Performs a DNS Lookup for an IPv4 or IPv6 address")
 
+	f.String("gp-from", "", "Probe locations as a comma-separated list")
+	f.Int("gp-limit", 1, "Limit the number of probes to use")
+
 	f.DurationP("timeout", "T", 5*time.Second, "Sets the timeout for a query")
 	f.Bool("search", true, "Use the search list provided in resolv.conf")
 	f.Int("ndots", -1, "Specify the ndots parameter")
@@ -162,7 +187,21 @@ func parseAndLoadFlags(f *flag.FlagSet) error {
 }
 
 func initializeApp(logger *slog.Logger, cfg *config) *app.App {
-	app := app.New(logger, buildVersion)
+	gpConfig := globalping.Config{
+		APIURL:    "https://api.globalping.io/v1",
+		AuthURL:   "https://auth.globalping.io",
+		UserAgent: fmt.Sprintf("doggo/%s (https://github.com/mr-karan/doggo)", buildVersion),
+	}
+	gpToken := os.Getenv("GLOBALPING_TOKEN")
+	if gpToken != "" {
+		gpConfig.AuthToken = &globalping.Token{
+			AccessToken: gpToken,
+			Expiry:      time.Now().Add(math.MaxInt64),
+		}
+	}
+	globlpingClient := globalping.NewClient(gpConfig)
+
+	app := app.New(logger, globlpingClient, buildVersion)
 
 	if err := k.Unmarshal("", &app.QueryFlags); err != nil {
 		logger.Error("Error loading args", "error", err)
