@@ -34,6 +34,11 @@ var appHelpTextTemplate = `{{ "NAME" | color "" "heading" }}:
   {{ printf "%-12s" $opt.Scheme | color "yellow" "" }}{{ printf "%-68s" $opt.Example }}{{ $opt.Description | color "cyan" "" }}
   {{- end }}
 
+{{ "SUBCOMMANDS" | color "" "heading" }}:
+  {{- range $opt := .Subcommands }}
+  {{ printf "%-30s" $opt.Flag | color "yellow" "" }}{{ $opt.Description }}
+  {{- end }}
+
 {{ "QUERY OPTIONS" | color "" "heading" }}:
   {{- range $opt := .QueryOptions }}
   {{ printf "%-30s" $opt.Flag | color "yellow" "" }}{{ $opt.Description }}
@@ -53,6 +58,11 @@ var appHelpTextTemplate = `{{ "NAME" | color "" "heading" }}:
   {{- range $opt := .OutputOptions }}
   {{ printf "%-30s" $opt.Flag | color "yellow" "" }}{{ $opt.Description }}
   {{- end }}
+
+{{ "GLOBALPING OPTIONS" | color "" "heading" }}:
+  {{- range $opt := .GlobalPingOptions }}
+  {{ printf "%-30s" $opt.Flag | color "yellow" "" }}{{ $opt.Description }}
+  {{- end }}
 `
 
 func renderCustomHelp() {
@@ -84,6 +94,7 @@ func renderCustomHelp() {
 			{"-q mrkaran.dev -t MX -n 1.1.1.1", "Using named arguments."},
 			{"mrkaran.dev --aa --ad", "Query with Authoritative Answer and Authenticated Data flags set."},
 			{"mrkaran.dev --cd --do", "Query with Checking Disabled and DNSSEC OK flags set."},
+			{"mrkaran.dev --gp-from Germany", "Query using Globalping API from a specific location."},
 		},
 		"TransportOptions": []TransportOption{
 			{"@udp://", "eg: @1.1.1.1", "initiates a UDP query to 1.1.1.1:53."},
@@ -93,6 +104,9 @@ func renderCustomHelp() {
 			{"@sdns://", "initiates a DNSCrypt or DoH query using a DNS stamp.", ""},
 			{"@quic://", "initiates a DOQ query.", ""},
 		},
+		"Subcommands": []Option{
+			{"completions [bash|zsh|fish]", "Generate the shell completion script for the specified shell."},
+		},
 		"QueryOptions": []Option{
 			{"-q, --query=HOSTNAME", "Hostname to query the DNS records for (eg mrkaran.dev)."},
 			{"-t, --type=TYPE", "Type of the DNS Record (A, MX, NS etc)."},
@@ -126,6 +140,10 @@ func renderCustomHelp() {
 			{"--debug", "Enable debug logging."},
 			{"--time", "Shows how long the response took from the server."},
 		},
+		"GlobalPingOptions": []Option{
+			{"--gp-from=Germany", "Query using Globalping API from a specific location."},
+			{"--gp-limit=INT", "Limit the number of probes to use from Globalping."},
+		},
 	}
 
 	tmpl, err := template.New("help").Funcs(template.FuncMap{
