@@ -4,10 +4,8 @@ import (
 	"context"
 	"crypto/tls"
 	"encoding/binary"
-	"errors"
 	"fmt"
 	"io"
-	"os"
 	"time"
 
 	"github.com/miekg/dns"
@@ -34,15 +32,20 @@ func NewDOQResolver(server string, resolverOpts Options) (Resolver, error) {
 	}, nil
 }
 
-// Lookup takes a dns.Question and sends them to DNS Server.
+// Lookup implements the Resolver interface
+func (r *DOQResolver) Lookup(ctx context.Context, questions []dns.Question, flags QueryFlags) ([]Response, error) {
+	return ConcurrentLookup(ctx, questions, flags, r.query, r.resolverOptions.Logger)
+}
+
+// query takes a dns.Question and sends them to DNS Server.
 // It parses the Response from the server in a custom output format.
-func (r *DOQResolver) Lookup(question dns.Question, flags QueryFlags) (Response, error) {
+func (r *DOQResolver) query(ctx context.Context, question dns.Question, flags QueryFlags) (Response, error) {
 	var (
 		rsp      Response
 		messages = prepareMessages(question, flags, r.resolverOptions.Ndots, r.resolverOptions.SearchList)
 	)
 
-	session, err := quic.DialAddr(context.TODO(), r.server, r.tls, nil)
+	session, err := quic.DialAddr(ctx, r.server, r.tls, nil)
 	if err != nil {
 		return rsp, err
 	}
@@ -59,54 +62,56 @@ func (r *DOQResolver) Lookup(question dns.Question, flags QueryFlags) (Response,
 		msg.Id = 0
 
 		// get the DNS Message in wire format.
-		var b []byte
-		b, err = msg.Pack()
+		b, err := msg.Pack()
 		if err != nil {
 			return rsp, err
 		}
 		now := time.Now()
 
-		var stream quic.Stream
-		stream, err = session.OpenStream()
+		stream, err := session.OpenStreamSync(ctx)
 		if err != nil {
 			return rsp, err
 		}
+		defer stream.Close()
 
-		var msgLen = uint16(len(b))
-		var msgLenBytes = []byte{byte(msgLen >> 8), byte(msgLen & 0xFF)}
-		_, err = stream.Write(msgLenBytes)
-		if err != nil {
+		msgLen := uint16(len(b))
+		msgLenBytes := []byte{byte(msgLen >> 8), byte(msgLen & 0xFF)}
+		if _, err = stream.Write(msgLenBytes); err != nil {
 			return rsp, err
 		}
 		// Make a QUIC request to the DNS server with the DNS message as wire format bytes in the body.
-		_, err = stream.Write(b)
-		if err != nil {
+		if _, err = stream.Write(b); err != nil {
 			return rsp, err
 		}
 
-		err = stream.SetDeadline(time.Now().Add(r.resolverOptions.Timeout))
-		if err != nil {
-			return rsp, err
-		}
+		// Use a separate context with timeout for reading the response
+		readCtx, cancel := context.WithTimeout(ctx, r.resolverOptions.Timeout)
+		defer cancel()
 
 		var buf []byte
-		buf, err = io.ReadAll(stream)
-		if err != nil {
-			if errors.Is(err, os.ErrDeadlineExceeded) {
-				return rsp, fmt.Errorf("timeout")
-			}
-			return rsp, err
-		}
-		rtt := time.Since(now)
+		errChan := make(chan error, 1)
+		go func() {
+			var err error
+			buf, err = io.ReadAll(stream)
+			errChan <- err
+		}()
 
-		_ = stream.Close()
+		select {
+		case err := <-errChan:
+			if err != nil {
+				return rsp, err
+			}
+		case <-readCtx.Done():
+			return rsp, fmt.Errorf("timeout reading response")
+		}
+
+		rtt := time.Since(now)
 
 		packetLen := binary.BigEndian.Uint16(buf[:2])
 		if packetLen != uint16(len(buf[2:])) {
 			return rsp, fmt.Errorf("packet length mismatch")
 		}
-		err = msg.Unpack(buf[2:])
-		if err != nil {
+		if err = msg.Unpack(buf[2:]); err != nil {
 			return rsp, err
 		}
 		// pack questions in output.
@@ -127,6 +132,14 @@ func (r *DOQResolver) Lookup(question dns.Question, flags QueryFlags) (Response,
 			// stop iterating the searchlist.
 			break
 		}
+
+		// Check if context is done after each iteration
+		select {
+		case <-ctx.Done():
+			return rsp, ctx.Err()
+		default:
+			// Continue to next iteration
+		}
 	}
 	return rsp, nil
 }
